#!perl
#
# This file is part of TBX-Checker
#
# This software is copyright (c) 2013 by Nathan Glenn.
#
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
#

# This test is generated by Dist::Zilla::Plugin::Test::Kwalitee
use strict;
use warnings;
use Test::More;   # needed to provide plan.
eval "use Test::Kwalitee";

plan skip_all => "Test::Kwalitee required for testing kwalitee" if $@;
